@@ -6,7 +6,7 @@ Copyright (c) 2013, Wladston Viana.
 """
 
 __author__ = 'Wladston Viana'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 __license__ = 'MIT'
 
 # Python.
@@ -19,6 +19,7 @@ from pymongo.son_manipulator import SONManipulator
 
 connection = None
 db = None
+_manipulators = []
 
 # MongoDB will not store dates with milliseconds.
 milli_trim = lambda x: x.replace(microsecond=int((x.microsecond/1000)*1000))
@@ -27,9 +28,15 @@ milli_trim = lambda x: x.replace(microsecond=int((x.microsecond/1000)*1000))
 def setup(database_name):
     global db, connection, _manipulators
 
+    if db:
+        raise Exception('Module was already configured.')
+
     connection = MongoClient('localhost', 27017, tz_aware=True)
     db = getattr(connection, database_name)
 
+    for  x in _manipulators:
+        db.add_son_manipulator(x)
+
     return db
 
 
@@ -124,7 +131,11 @@ class ModelType(type):
         rich_cls = super(ModelType, cls).__new__(cls, name, bases, dct)
 
         if rich_cls.__name__ not in ['Model', 'Document', 'TimeStampedModel']:
-            db.add_son_manipulator(_ModelManipulator(rich_cls))
+            if db:
+                db.add_son_manipulator(_ModelManipulator(rich_cls))
+
+            else:
+                _manipulators.append(_ModelManipulator(rich_cls))
 
         return rich_cls
 
